import { useEffect, useState } from 'react';
import './style.css';
import { usePackageStore, Package } from './store.ts';
import { Link2, SquareArrowOutUpRight } from 'lucide-react';
import { useConfigStore } from '@/apps/config/store';
import { useConfirm } from './Confirm.tsx';
import { AlertDialogAction } from '@/components/ui/alert-dialog.tsx';
const BASE_REGISTRY = 'https://kevisual.cn';
export const PackageManager = () => {
  const { shopPackages, installedPackages, getInstalledPackages, getShopPackages, uninstallPackage, installPackage } = usePackageStore();
  const { pageApi, pageStoreApi } = useConfigStore();
  const [confirmId, setConfirmId] = useState<string>('');

  const { confirm, module } = useConfirm({
    confrimProps: {
      title: '应用类型',
      description: '确认应用类型，web 或者 app, web 为前端的访问界面。',
      footer: (
        <>
          <AlertDialogAction
            className='cursor-pointer'
            onClick={() => {
              handleInstall(confirmId, 'web');
            }}>
            Web
          </AlertDialogAction>
          <AlertDialogAction className='cursor-pointer' onClick={() => handleInstall(confirmId, 'app')}>
            App
          </AlertDialogAction>
        </>
      ),
    },
  });
  useEffect(() => {
    getInstalledPackages();
    getShopPackages();
  }, []);

  const getPackageStatus = (pkg: Package) => {
    const installed = installedPackages.find((p) => p.id === pkg.id || (p.user === pkg.user && p.key === pkg.key));

    if (!installed) return { status: 'not-installed' };
    if (installed.version !== pkg.version) return { status: 'update-available' };
    console.log('installed', installed);
    return { status: 'installed', appType: installed.appType };
  };

  const handleInstall = (id: string, type?: 'web' | 'app') => {
    if (!type) {
      setConfirmId(id);
      confirm();
      return;
    }

    const pkg = shopPackages.find((p) => p.id === id);
    if (pkg) {
      installPackage({
        id: `${pkg.user}/${pkg.key}`,
        force: false,
        type: pkg.appType || 'web',
      });
    }
  };

  const handleUpdate = (id: string) => {
    const pkg = shopPackages.find((p) => p.id === id);
    if (pkg) {
      installPackage({
        id: `${pkg.user}/${pkg.key}`,
        force: false,
        type: pkg.appType || 'web',
      });
    }
  };

  const handleReinstall = (id: string) => {
    const pkg = installedPackages.find((p) => p.id === id);
    if (pkg) {
      installPackage({
        id: `${pkg.user}/${pkg.key}`,
        force: false,
        type: pkg.appType || 'web',
      });
    }
  };

  const handleUninstall = (id: string) => {
    const pkg = installedPackages.find((p) => p.id === id);
    if (pkg) {
      uninstallPackage({ id: `${pkg.user}/${pkg.key}`, type: pkg.appType });
    }
  };

  const getActionButton = (status: string, pkg: Package) => {
    switch (status) {
      case 'not-installed':
        return (
          <button className='button button-install' onClick={() => handleInstall(pkg.id)}>
            Install
          </button>
        );
      case 'update-available':
        return (
          <button className='button button-update' onClick={() => handleUpdate(pkg.id)}>
            Update
          </button>
        );
      case 'installed':
        return (
          <button className='button button-reinstall' onClick={() => handleReinstall(pkg.id)}>
            Reinstall
          </button>
        );
    }
  };
  const handleOpenWindow = (pkg: Package) => {
    let baseUrl = pageStoreApi;
    if (!baseUrl) {
      baseUrl = new URL(window.location.href).origin;
    }
    const path = `/${pkg.user}/${pkg.key}`;
    window.open(`${baseUrl}${path}`, '_blank');
  };
  const handleOpenClientWindow = (pkg: Package) => {
    const baseUrl = new URL(window.location.href).origin;
    const path = `/${pkg.user}/${pkg.key}`;
    window.open(`${baseUrl}${path}`, '_blank');
  };
  return (
    <div id='app' className=''>
      <h1>Package Manager</h1>
      <div className='package-list'>
        {shopPackages.map((pkg) => {
          const pkgStatus = getPackageStatus(pkg);
          const status = pkgStatus.status;
          const isInstalled = status !== 'not-installed';
          return (
            <div key={pkg.id} className='package-card'>
              <h2>{pkg.title}</h2>
              <p className='description'>{pkg.description}</p>
              <div className='package-info'>
                <span>Version: {pkg.version}</span>
                <span>User: {pkg.user}</span>
              </div>
              <div className='actions'>
                {getActionButton(status, pkg)}

                {status !== 'not-installed' && (
                  <button className='button button-uninstall' onClick={() => handleUninstall(pkg.id)}>
                    Uninstall
                  </button>
                )}
                <div className='flex gap-2'>
                  <div className='cursor-pointer p-2 rounded-md bg-amber-500 text-white'>
                    <SquareArrowOutUpRight onClick={() => handleOpenWindow(pkg)} />
                  </div>
                  {isInstalled && pkgStatus?.appType === 'web' && (
                    <div className='cursor-pointer p-2 rounded-md bg-amber-500 text-white'>
                      <Link2 onClick={() => handleOpenClientWindow(pkg)} />
                    </div>
                  )}
                </div>
              </div>
            </div>
          );
        })}
      </div>
      {module}
    </div>
  );
};

export default PackageManager;
