import { create } from 'zustand';
import { clientQuery as client, query } from '@/modules/query';
import { toast } from 'react-toastify';
import { qa, qs } from './query.ts';
export type Package = {
  id: string;
  name?: string;
  version?: string;
  description?: string;
  title?: string;
  user?: string;
  key?: string;
  appType?: any;
};
export type InstallOptions = {
  id: string;
  type?: 'web' | 'app';
  /**
   * 会自动清理之前安装的内容
   */
  force?: boolean;
  yes?: boolean;
};
export type UninstallOptions = {
  id: string;
  type?: 'web' | 'app';
  yes?: boolean;
};
type PackageStore = {
  installedPackages: Package[];
  shopPackages: Package[];
  setInstalledPackages: (packages: Package[]) => void;
  setShopPackages: (packages: Package[]) => void;
  getInstalledPackages: () => Promise<any>;
  getShopPackages: () => Promise<Package[]>;
  uninstallPackage: (data: UninstallOptions) => Promise<void>;
  installPackage: (data: InstallOptions) => Promise<void>;
};
export const usePackageStore = create<PackageStore>((set, get) => ({
  installedPackages: [],
  shopPackages: [],
  setInstalledPackages: (packages) => set({ installedPackages: packages }),
  setShopPackages: (packages) => set({ shopPackages: packages }),
  getInstalledPackages: async () => {
    type ListPackage = {
      appInfo: Package;
      id?: string;
      [key: string]: any;
    };
    const res = await qs.appDefine.queryChain('listInstalled').get<ListPackage[]>({});
    if (res.code === 200) {
      const listPackages = res.data || [];
      const installed = listPackages.map((item) => {
        return { appType: item.appType, ...item.appInfo };
      });

      set({ installedPackages: installed });
    }
    return res;
  },
  getShopPackages: async () => {
    const res = await qa.post({
      path: 'app',
      key: 'public-list',
    });
    if (res.code === 200) {
      set({ shopPackages: res.data });
    }
    return res.data;
  },
  uninstallPackage: async (data: UninstallOptions) => {
    if (typeof data.yes === 'undefined') data.yes = true;
    const res = await qs.post({
      path: 'shop',
      key: 'uninstall',
      data,
    });
    if (res.code === 200) {
      get().getInstalledPackages();
      toast.success('Package uninstalled successfully');
    } else {
      toast.error(res.message || 'Failed to uninstall package');
    }
    console.log('uninstallPackage', res);
  },
  installPackage: async (data: InstallOptions) => {
    const toastId = toast.loading('Installing package...');
    if (typeof data.yes === 'undefined') data.yes = true;
    const res = await client.post({
      path: 'shop',
      key: 'install',
      data,
    });
    toast.dismiss(toastId);
    if (res.code === 200) {
      get().getInstalledPackages();
      toast.success('Package installed successfully');
    } else {
      toast.error(res.message || 'Failed to install package');
    }
    console.log('installPackage', res);
  },
}));

const installedPackages: Package[] = [
  { user: 'test', key: 'test-key', version: '1.0.0', id: '1', title: '', description: '' },
  { user: 'demo', key: 'demo-package', version: '1.2.0', id: '2', title: '', description: '' },
];

const mockPackages: Package[] = [
  {
    id: '1',
    title: 'Demo Package 1',
    description: 'A test package for demonstration',
    version: '1.0.0',
    user: 'test',
    key: 'test-key',
  },
  {
    id: '2',
    title: 'Demo Package 2',
    description: 'Another test package with updates',
    version: '2.0.0',
    user: 'demo',
    key: 'demo-package',
  },
  {
    id: '3',
    title: 'New Package',
    description: "A package that hasn't been installed yet",
    version: '1.0.0',
    user: 'demo',
    key: 'new-package',
  },
];
